#! /bin/bash
#*********************************************************************************************************************************************************
#
#   This script installs MAGIX in the current directory
#   Copyright (C) 2012 - 2020  Thomas Moeller
#
#   I. Physikalisches Institut, University of Cologne
#
#
#   Usage:
#
#   - Compile only the MPI versions:
#
#       "install.sh --mpi" or "install.sh --MPI" or "install.sh mpi" or "install.sh MPI"
#
#
#   - Compile only the SMP versions:
#
#       "install.sh --smp" or "install.sh --SMP" or "install.sh smp" or "install.sh SMP"
#
#
#
#   Versions of the program:
#
#   Who           When         What
#
#   T. Moeller    2012-03-08   Initial version
#   T. Moeller    2020-02-07   current version 2.0.8
#
#
#
#   License:
#
#    GNU GENERAL PUBLIC LICENSE
#    Version 3, 29 June 2007
#    (Copyright (C) 2007 Free Software Foundation, Inc. <http://fsf.org/>)
#
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#*********************************************************************************************************************************************************


#---------------------------------------------------------------------------------------------------------------------------------------------------------
# depending on the command line arguments, compile algorithms with mpi, smp or gpu or combination of that techniques
defaultParallel="smp"
if [ "$1" = "--mpi" -o "$1" = "--MPI" -o "$1" = "mpi" -o "$1" = "MPI" ]; then
    defaultParallel="mpi"
elif [ "$1" = "--smp" -o "$1" = "--SMP" -o "$1" = "smp" -o "$1" = "SMP" ]; then
    defaultParallel="smp"
fi

# Debug
# echo 'defaultParallel = '$defaultParallel


#---------------------------------------------------------------------------------------------------------------------------------------------------------
# compile all FORTRAN-algorithms
echo "Compile local CFITSIO library ... "
cfitsioPath=$(pwd)"/Modules/External_Packages/CFITSIO/src"
cfitsioBIN=$cfitsioPath/../bin
cd $cfitsioPath/
rm -rf $cfitsioBIN/libcfitsio.a
rm -rf $cfitsioPath/lib/libcfitsio.a
rm -rf $cfitsioPath/lib64/libcfitsio.a
./configure --prefix=$cfitsioPath > cfitsio.out 2>&1
make >> cfitsio.out 2>&1
make install >> cfitsio.out 2>&1
BinPath1=$cfitsioPath/lib/libcfitsio.a
BinPath2=$cfitsioPath/lib64/libcfitsio.a
if test -f "$BinPath1"; then
    mv $BinPath1 $cfitsioBIN/
fi
if test -f "$BinPath2"; then
    mv $BinPath2 $cfitsioBIN/
fi
make clean >> cfitsio.out 2>&1
cd ../../../


# compile all FORTRAN-algorithms
echo "Compile all FORTRAN-algorithms ... "
cd Bees/
make $defaultParallel
cd ../Levenberg-Marquardt/
make $defaultParallel
cd ../Simulated-Annealing/
make $defaultParallel
cd ../PSO/
make $defaultParallel
cd ../Genetic/
make $defaultParallel
cd ../Nested-Sampling/
make $defaultParallel
cd ../Model-Function_Call/
make $defaultParallel
cd ..
cd ..
echo "Compile all FORTRAN-algorithms ... done!"


#---------------------------------------------------------------------------------------------------------------------------------------------------------
# compile model function
echo "Compile model function ... "
cd Fit-Functions/solid-state/Drude-Lorentz_conv/
make all
cd ../..
echo "Compile model function ... done!"


# we've done
#---------------------------------------------------------------------------------------------------------------------------------------------------------

